@@ -5,7 +5,7 @@ use slab::Slab;
 use std::sync::atomic::{AtomicUsize, Ordering};
 use std::sync::Arc;
 use std::time::{Duration, Instant};
-use std::{cmp, fmt, io, iter, thread};
+use std::{cmp, fmt, io, thread};
 
 mod convert {
     use std::time::Duration;
@@ -175,11 +175,13 @@ impl<T> Timer<T> {
         let num_slots = num_slots.next_power_of_two();
         let capacity = capacity.next_power_of_two();
         let mask = (num_slots as u64) - 1;
-        let wheel = iter::repeat(WheelEntry {
-            next_tick: TICK_MAX,
-            head: EMPTY,
-        })
-        .take(num_slots)
+        let wheel = std::iter::repeat_n(
+            WheelEntry {
+                next_tick: TICK_MAX,
+                head: EMPTY,
+            },
+            num_slots,
+        )
         .collect();
 
         Timer {
