@@ -5,7 +5,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/charmcli/status/1861865055370756430',
     username: 'charmcli',
-    source: '/rio/assets/mentions/charm.jpg',
+    source: '/assets/mentions/charm.jpg',
     quote: (
       <>
         🌈 Rio is one of those rare software projects that delivers S+ performance while maintaining fun and playfulness at its core.
@@ -15,7 +15,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/GoReleaser/status/1861895213091795002',
     username: 'GoReleaser',
-    source: '/rio/assets/mentions/goreleaser.jpg',
+    source: '/assets/mentions/goreleaser.jpg',
     quote: (
       <>
         Rio is pretty amazing! Excellent work by @raphamorims ✌️
@@ -25,7 +25,7 @@ const MENTIONS = [
   {
     url: 'https://fosstodon.org/@orhun/113375636616878019',
     username: 'Orhun Parmaksız',
-    source: '/rio/assets/mentions/orhun.png',
+    source: '/assets/mentions/orhun.png',
     quote: (
       <>
         One of the few terminal emulators out there with kickass features!
@@ -35,7 +35,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/kristoferlund/status/1850287561295692226',
     username: 'Kristofer Lund',
-    source: '/rio/assets/mentions/kristoferlund.jpg',
+    source: '/assets/mentions/kristoferlund.jpg',
     quote: (
       <>
         Love Rio terminal by @raphamorims! Written in Rust = super fast, plus has kick-ass features like this. 👊💥
@@ -45,7 +45,7 @@ const MENTIONS = [
   {
     url: 'https://mas.to/@appelgriebsch@fosstodon.org/113491434980520006',
     username: 'Andreas Gerlach',
-    source: '/rio/assets/mentions/andreasgerlach.jpeg',
+    source: '/assets/mentions/andreasgerlach.jpeg',
     quote: (
       <>
         With the recent release of #rio earlier this week it has all the features and polish I need on daily basis, so it became my daily driver immediately....  thanks so much @mustache
@@ -55,7 +55,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/pikuma/status/1859327979869909260',
     username: 'pikuma.com',
-    source: '/rio/assets/mentions/pikuma.jpg',
+    source: '/assets/mentions/pikuma.jpg',
     quote: (
       <>
         I've been using #Rio terminal by @raphamorims this week and it's super nice. Very easy to use and config.
@@ -65,7 +65,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/nahuakang/status/1861156311410311305',
     username: '@nahuakang',
-    source: '/rio/assets/mentions/nahuakang.jpg',
+    source: '/assets/mentions/nahuakang.jpg',
     quote: (
       <>
         I wish I had known about the #Rio terminal crafted by @raphamorims earlier. It's easy to configure and has great aesthetics out of the box. It's a software made with 💜
@@ -75,19 +75,17 @@ const MENTIONS = [
   {
     url: 'https://twitter.com/jaijams/status/1716815864975270005',
     username: '@jaijams',
-    source: '/rio/assets/mentions/jaijams.jpg',
+    source: '/assets/mentions/jaijams.jpg',
     quote: (
       <>
-        I have been using the Rio terminal (https://raphamorim.io/rio/) for 6
-        months. OMG! Rio is my No.1 terminal ♥️ and is super fast 🚀 . Love
-        using it daily 🎉
+        I have been using the Rio terminal for 6 months. OMG! Rio is my No.1 terminal ♥️ and is super fast 🚀 . Love using it daily 🎉
       </>
     ),
   },
   {
     url: 'https://twitter.com/mcsmonte/status/1660949303089586177',
     username: '@mcsmonte',
-    source: '/rio/assets/mentions/mcsmonte.jpg',
+    source: '/assets/mentions/mcsmonte.jpg',
     quote: (
       <>
         This week I'm testing rio, a rust based terminal and I need to say: It's
@@ -124,7 +122,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/ferfabricio/status/1789425980357886355',
     username: '@ferfabricio',
-    source: '/rio/assets/mentions/ferfabricio.jpg',
+    source: '/assets/mentions/ferfabricio.jpg',
     quote: (
       <>
         Eu comecei a usar o Rio term faz uns dias e ta sendo uma experiência
@@ -135,7 +133,7 @@ const MENTIONS = [
   {
     url: '#',
     username: 'Simon Nyberg',
-    source: '/rio/assets/mentions/simonnyberg.png',
+    source: '/assets/mentions/simonnyberg.png',
     quote: (
       <>
         Rio has become my standard terminal emulator for some time and it works well in professional use. Raphael is doing a great work and is awesome at listening to feedback to the community for new and improved features.
@@ -145,7 +143,7 @@ const MENTIONS = [
   {
     url: '#',
     username: 'Jader Gomes',
-    source: '/rio/assets/mentions/jadergomes.jpg',
+    source: '/assets/mentions/jadergomes.jpg',
     quote: (
       <>
         Have been using Rio for few weeks and enjoying the experience so far. I love the colors and the visual around it.
@@ -155,7 +153,7 @@ const MENTIONS = [
   {
     url: '#',
     username: 'Daria Edlund',
-    source: '/rio/assets/mentions/dariaedlund.png',
+    source: '/assets/mentions/dariaedlund.png',
     quote: (
       <>
         Installed Rio recently and am impressed how smooth and fast this terminal is. Already set up as my default go-to terminal! Looking forward to the continued development and what is to come. Keep up the awesome job Raphael!
@@ -165,7 +163,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/avelinorun/',
     username: 'Thiago Avelino',
-    source: '/rio/assets/mentions/avelinorun.jpg',
+    source: '/assets/mentions/avelinorun.jpg',
     quote: (
       <>
         It is a privilege to be invited to beta test Rio! It has brought me closer to the code of the project, and I have learned a lot about how to develop a terminal emulator.
@@ -175,7 +173,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/mkenzo_8',
     username: '@mkenzo_8',
-    source: '/rio/assets/mentions/mkenzo_8.jpg',
+    source: '/assets/mentions/mkenzo_8.jpg',
     quote: (
       <>
         Rio tiene el potencial de ser de las terminales mas rápidas ⚡ y mas personalizables que hay, es una locura.
@@ -185,7 +183,7 @@ const MENTIONS = [
   {
     url: 'https://x.com/pedronauck',
     username: '@pedronauck',
-    source: '/rio/assets/mentions/pedronauck.jpg',
+    source: '/assets/mentions/pedronauck.jpg',
     quote: (
       <>
         Rapha is not only one of the most talented programmers I've ever met but also one of the best friends I've had in my life. It’s no surprise to me that Rio embodies such exceptional quality and speed. As a terminal emulator, Rio has set a new standard—it’s unquestionably the go-to solution.
