@@ -20,7 +20,7 @@ impl Messenger {
     pub fn send_write<B: Into<Cow<'static, [u8]>>>(&self, data: B) {
         let bytes = data.into();
         // terminal hangs if we send 0 bytes through.
-        if bytes.len() == 0 {
+        if bytes.is_empty() {
             return;
         }
 
